@@ -41,7 +41,7 @@ def _clean_table(table: str) -> str:
     # replace line breaks "\n" with html tag <br />, however, leave end-of-line
     # line breaks (eol_lb) intact
     eol_lb = "|\n"
-    placeholder = "$%!?"  # arbitrary string that never appears naturally
+    placeholder = "\x1f"  # unit separator control character (ASCII control char 31)
     table = (
         table.replace(eol_lb, placeholder)
         .replace("\n", "<br />")
@@ -146,14 +146,18 @@ def metadata_from_config(config_path: Union[str, Path]) -> ModelCardData:
 
     with open(config_path) as f:
         config = json.load(f)
-
-    card_data = ModelCardData()
+    card_data = ModelCardData(
+        model_format=config.get("sklearn", {}).get("model_format", {})
+    )
     card_data.library_name = "sklearn"
     card_data.tags = ["sklearn", "skops"]
     task = config.get("sklearn", {}).get("task", None)
     if task:
         card_data.tags += [task]
     card_data.model_file = config.get("sklearn", {}).get("model", {}).get("file")  # type: ignore
+    if config.get("sklearn", {}).get("use_intelex"):
+        card_data.tags.append("scikit-learn-intelex")
+
     example_input = config.get("sklearn", {}).get("example_input", None)
     # Documentation on what the widget expects:
     # https://huggingface.co/docs/hub/models-widgets-examples
@@ -195,7 +199,7 @@ def split_subsection_names(key: str) -> list[str]:
         The individual (sub)sections.
 
     """
-    placeholder = "$%!?"  # arbitrary sting that never appears naturally
+    placeholder = "\x1f"  # unit separator control character (ASCII control char 31)
     key = key.replace("\\/", placeholder)
     parts = (part.strip() for part in key.split("/"))
     return [part.replace(placeholder, "/") for part in parts]
@@ -683,6 +687,11 @@ class Card:
         val: str or Formattable
             The value to assign to the (sub)section.
 
+        Returns
+        -------
+        Section instance
+            The section that has been added or modified.
+
         """
         *subsection_names, leaf_node_name = split_subsection_names(key)
         section = self._select(subsection_names)
