@@ -7,10 +7,12 @@ import pytest
 def pandas_not_installed():
     # patch import so that it raises an ImportError when trying to import
     # pandas. This works because pandas is only imported lazily.
+    orig_import = __import__
+
     def mock_import(name, *args, **kwargs):
         if name == "pandas":
             raise ImportError
-        return __import__(name, *args, **kwargs)
+        return orig_import(name, *args, **kwargs)
 
     with patch("builtins.__import__", side_effect=mock_import):
         yield
